# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blueprint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62lueprint.proto\x12\x13\x63onnector.blueprint\"\x12\n\x10\x42lueprintRequest\"\x13\n\x11\x42lueprintResponse2k\n\x10\x42lueprintService\x12W\n\x04Read\x12%.connector.blueprint.BlueprintRequest\x1a&.connector.blueprint.BlueprintResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blueprint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLUEPRINTREQUEST']._serialized_start=40
  _globals['_BLUEPRINTREQUEST']._serialized_end=58
  _globals['_BLUEPRINTRESPONSE']._serialized_start=60
  _globals['_BLUEPRINTRESPONSE']._serialized_end=79
  _globals['_BLUEPRINTSERVICE']._serialized_start=81
  _globals['_BLUEPRINTSERVICE']._serialized_end=188
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: platform.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eplatform.proto\x12\x12\x63onnector.platform\"\x11\n\x0fPlatformRequest\"\x12\n\x10PlatformResponse2f\n\x0fPlatformService\x12S\n\x04Read\x12#.connector.platform.PlatformRequest\x1a$.connector.platform.PlatformResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'platform_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLATFORMREQUEST']._serialized_start=38
  _globals['_PLATFORMREQUEST']._serialized_end=55
  _globals['_PLATFORMRESPONSE']._serialized_start=57
  _globals['_PLATFORMRESPONSE']._serialized_end=75
  _globals['_PLATFORMSERVICE']._serialized_start=77
  _globals['_PLATFORMSERVICE']._serialized_end=179
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import service_pb2 as service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x12\x13\x63onnector.connector\x1a\x19google/protobuf/any.proto\x1a\rservice.proto\"\xb1\x01\n\tConnector\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\x12+\n\x07service\x18\x05 \x01(\x0b\x32\x1a.connector.service.Service\x12)\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x88\x01\x01\x42\t\n\x07_config\"$\n\x11\x44ispatcherRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"%\n\x12\x44ispatcherResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\'\n\x11\x43onnectorsRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\"H\n\x12\x43onnectorsResponse\x12\x32\n\nconnectors\x18\x01 \x03(\x0b\x32\x1e.connector.connector.Connector\"3\n\x10\x43onnectorRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"G\n\x11\x43onnectorResponse\x12\x32\n\nconnectors\x18\x01 \x01(\x0b\x32\x1e.connector.connector.Connector2s\n\x10\x43onnectorService\x12_\n\nDispatcher\x12&.connector.connector.DispatcherRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONNECTOR']._serialized_start=83
  _globals['_CONNECTOR']._serialized_end=260
  _globals['_DISPATCHERREQUEST']._serialized_start=262
  _globals['_DISPATCHERREQUEST']._serialized_end=298
  _globals['_DISPATCHERRESPONSE']._serialized_start=300
  _globals['_DISPATCHERRESPONSE']._serialized_end=337
  _globals['_CONNECTORSREQUEST']._serialized_start=339
  _globals['_CONNECTORSREQUEST']._serialized_end=378
  _globals['_CONNECTORSRESPONSE']._serialized_start=380
  _globals['_CONNECTORSRESPONSE']._serialized_end=452
  _globals['_CONNECTORREQUEST']._serialized_start=454
  _globals['_CONNECTORREQUEST']._serialized_end=505
  _globals['_CONNECTORRESPONSE']._serialized_start=507
  _globals['_CONNECTORRESPONSE']._serialized_end=578
  _globals['_CONNECTORSERVICE']._serialized_start=580
  _globals['_CONNECTORSERVICE']._serialized_end=695
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: company.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcompany.proto\x12\x11\x63onnector.company\"\x10\n\x0e\x43ompanyRequest\"\x11\n\x0f\x43ompanyResponse2\xd1\x02\n\x0e\x43ompanyService\x12L\n\x03Get\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse\x12O\n\x06\x43reate\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse\x12O\n\x04Read\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponse0\x01\x12O\n\x06Update\x12!.connector.company.CompanyRequest\x1a\".connector.company.CompanyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'company_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPANYREQUEST']._serialized_start=36
  _globals['_COMPANYREQUEST']._serialized_end=52
  _globals['_COMPANYRESPONSE']._serialized_start=54
  _globals['_COMPANYRESPONSE']._serialized_end=71
  _globals['_COMPANYSERVICE']._serialized_start=74
  _globals['_COMPANYSERVICE']._serialized_end=411
# @@protoc_insertion_point(module_scope)
